@@ -3,6 +3,7 @@ package Dancer::Template::Abstract;
 use strict;
 use warnings;
 use Carp;
+use Storable 'dclone';
 
 use Dancer::Logger;
 use Dancer::Factory::Hook;
@@ -40,7 +41,7 @@ sub view {
 
     for my $template ($self->_template_name($view)) {
         my $view_path = path($views_dir, $template);
-        return $view_path if -e $view_path;
+        return $view_path if -f $view_path;
     }
 
     # No matching view path was found
@@ -145,18 +146,18 @@ sub _prepare_tokens_options {
     $tokens ||= {};
     $tokens->{perl_version}   = $];
     $tokens->{dancer_version} = $Dancer::VERSION;
-    $tokens->{settings}       = Dancer::Config->settings;
+    $tokens->{settings}       = dclone(Dancer::Config->settings);
 
     # If we're processing a request, also add the request object, params and
     # vars as tokens:
     if (my $request = Dancer::SharedData->request) {
         $tokens->{request}        = $request;
-        $tokens->{params}         = $request->params;
-        $tokens->{vars}           = Dancer::SharedData->vars;
+        $tokens->{params}         = dclone($request->params);
+        $tokens->{vars}           = dclone(Dancer::SharedData->vars);
     }
 
     Dancer::App->current->setting('session')
-      and $tokens->{session} = Dancer::Session->get;
+      and $tokens->{session} = dclone(Dancer::Session->get);
 
     return ($tokens, $options);
 }
@@ -174,7 +175,7 @@ sub template {
 
     if ($view) {
         # check if the requested view exists
-        my $view_path = $engine->view($view);
+        my $view_path = $engine->view($view) || '';
         if ($engine->view_exists($view_path)) {
             $content = $engine->apply_renderer($view, $tokens);
         } else {
@@ -202,7 +203,7 @@ sub template {
     )->render();
 }
 
-sub view_exists { return -e $_[1] }
+sub view_exists { return defined $_[1] &&  -f $_[1] }
 
 1;
 __END__
@@ -310,6 +311,17 @@ system with multiple document roots (like L<Text::XSlate> or
 L<Template>), you can override this method to always return true, and
 therefore skip this check.
 
+=item B<view_exists($view_path)>
+
+By default, Dancer::Template::Abstract checks to see if it can find the
+view file calling C<view_exists($path_to_file)>. If not, it will
+generate a nice error message for the user.
+
+If you are using extending Dancer::Template::Abstract to use a template
+system with multiple document roots (like L<Text::XSlate> or
+L<Template>), you can override this method to always return true, and
+therefore skip this check.
+
 =item B<layout($layout, $tokens, $content)>
 
 The default behavior of this method is to merge a content with a layout.  The
